#!/usr/bin/env python
# -*- coding: utf-8 -*-

# import
from pylab import *
from numpy import *
import glob
import netCDF4
import matplotlib.gridspec as gridspec
from mpl_toolkits.basemap import Basemap
import time

from sklearn.preprocessing import scale
import sklearn.cluster.hierarchical as hclust
from sklearn.cluster import KMeans
pdist=hclust.hierarchy.distance.pdist
squareform=hclust.hierarchy.distance.squareform
dendrogram=hclust.hierarchy.dendrogram
linkage=hclust.hierarchy.linkage


### ERAI
# cherche fichiers
fic=glob.glob('/bdd/ERAI/NETCDF/GLOBAL_075/1xmonthly/AN_SF/200*/tcwv*.nc')
tcwv=[]
for i in xrange(len(fic)):
    ficnc = netCDF4.Dataset(fic[i])
    if (i==0):
        tcwv=ficnc.variables['tcwv'][:]
    else:
        tcwv = concatenate((tcwv,ficnc.variables['tcwv'][:]))

lat = ficnc.variables['lat'][:]
lon = ficnc.variables['lon'][:]

# masque terre/mer
ficnc = netCDF4.Dataset('/bdd/ERAI/NETCDF/GLOBAL_075/1xmonthly/AN_SF/2000/lsm.2000.asmei.GLOBAL_075.nc')#0=sea/1=land
lsm=ficnc.variables['lsm'][:]

# extract tropiques
bor=35
tcwv=tcwv[:,(lat>=-bor) & (lat<=bor),:]
lsm=lsm[1,(lat>=-bor) & (lat<=bor),:]
lat=lat[(lat>=-bor) & (lat<=bor)]

## #moyenne par pas de 2 en lonlat: equivalent grille de 1.5
## s_wv=shape(tcwv)
## latmoy=[lat[i*2:i*2+2].mean() for i in xrange(len(lat)/2)]
## lonmoy=[lon[j*2:j*2+2].mean() for j in xrange(len(lon)/2)]
## tcwv_erai=zeros((s_wv[0],len(lat_erai),len(lon_erai)))
## lsm_erai=zeros((len(lat_erai),len(lon_erai)))
## for i in xrange(len(lat)/2):
##     for j in xrange(len(lon)/2):
##         tcwv_erai[:,i,j]=mean(mean(tcwv[:,i*2:i*2+2,j*2:j*2+2],2),1)
##         lsm_erai[i,j]=mean(lsm[i*2:i*2+2,j*2:j*2+2])

lat_erai=lat.copy()
lon_erai=lon.copy()
tcwv_moy=tcwv.copy()
lsm_erai=lsm.copy()
resol=lat_erai[0]-lat_erai[1]

# matrice (obs,info) pour classification
s_wv=shape(tcwv_moy)
tcwv_vec=reshape(tcwv_moy,(s_wv[0],s_wv[1]*s_wv[2]))
lsm_vec=reshape(lsm_erai,s_wv[1]*s_wv[2])
datasea=transpose(tcwv_vec[:,(lsm_vec==0.)])
dataland=transpose(tcwv_vec[:,(lsm_vec==1.)])

###########
### SEA ###
###########
###K-means ni centre ni reduit
nbc=6
kmeans = KMeans(init='k-means++', n_clusters=nbc)
kmeans.fit(datasea)
classif=kmeans.labels_
# reforme matrice lat_erai/lon
classif_mat=zeros((s_wv[1]*s_wv[2]))
classif_mat[(lsm_vec==1.)]=nan
classif_mat[(lsm_vec==0.)]=classif
classif_mat=reshape(classif_mat,(s_wv[1],s_wv[2]))

# centre
datasea_c=scale(datasea,axis=1,with_mean=True,with_std=False)
### Kmeans cross
nbc_f=2
kmeans = KMeans(init='k-means++', n_clusters=nbc_f)
classif_f=zeros(size(datasea,0))
for i in xrange(nbc):
    kmeans.fit(datasea_c[classif==i,:])
    classif_f[classif==i]=kmeans.labels_+i*2

# reforme matrice lat/lon
classif_sea=zeros((s_wv[1]*s_wv[2]))
classif_sea[(lsm_vec==1.)]=0.
classif_sea[(lsm_vec==0.)]=classif_f+1#+1 pr pas de classe 0
classif_sea=reshape(classif_sea,(s_wv[1],s_wv[2]))

############
### LAND ###
############
###K-means ni centre ni reduit
nbc_l=5
kmeans = KMeans(init='k-means++', n_clusters=nbc_l)
kmeans.fit(dataland)
classif=kmeans.labels_
# reforme matrice lat_erai/lon
classif_land=zeros((s_wv[1]*s_wv[2]))
classif_land[(lsm_vec==0.)]=0.
# differencie les classes terre des classes mer
classif_land[(lsm_vec==1.)]=classif+(nbc*nbc_f)+1
classif_land=reshape(classif_land,(s_wv[1],s_wv[2]))

#############
### GLOBE ###
#############
classif_glob=(classif_sea+classif_land)

# retire les cotes et les altitudes superieures a 1000m
altmax=1000
classif_filtre=classif_glob.copy()
altnc = netCDF4.Dataset('/homedata/eymard/varamma_d/MASK/ETOPO1_Ice_g_gmt4.nc')
lon_z=altnc.variables['lon'][:]
lat_z=altnc.variables['lat'][:]
z=altnc.variables['z'][:]

lon_z[lon_z<0]=lon_z[lon_z<0]+360

t1=time.clock()
for i in xrange(len(lon_erai)):
    temp=z[:,(lon_z >= lon_erai[i]-resol/2.) & (lon_z < lon_erai[i]+resol/2.)]
    for j in xrange(len(lat_erai)):
        tempbis=temp[(lat_z >= lat_erai[j]-resol/2.) & (lat_z < lat_erai[j]+resol/2.),:]
        if any(tempbis>altmax) | (any(tempbis<0) & any(tempbis>0)):
            classif_filtre[j,i]=NaN

t2=time.clock()
print t2-t1
# Stocke dans .nc

#cree fic
ncfile = netCDF4.Dataset('classifERAI_Trop.nc','w',format='NETCDF3_CLASSIC')
#definit dimension
ncfile.createDimension('lat',len(lat_erai))
ncfile.createDimension('lon',len(lon_erai))
#cree variables dimensions
lats = ncfile.createVariable('lat',dtype('float32').char,('lat',))
lons = ncfile.createVariable('lon',dtype('float32').char,('lon',))
lats.units = 'degrees_north'
lons.units = 'degrees_east'
lats[:] = lat_erai
lons[:] = lon_erai
#cree variables
classif_fic = ncfile.createVariable('classif_tot',dtype('float32').char,('lat','lon'))
classif_fic.description = 'ERAI Classification\nfrom kmeans with 2000-2009 years\nsea: %d class (n°%d-%d)\nland: %d class (n°%d-%d)'%(nbc*nbc_f,1,nbc*nbc_f,nbc_l,nbc*nbc_f+1,nbc*nbc_f+nbc_l)
classif_fic[:] = classif_glob
classif_fic = ncfile.createVariable('classif',dtype('float32').char,('lat','lon'))
classif_fic.description = 'same as classif_tot but without coast and altitude upper %d m'%(altmax)
classif_fic[:] = classif_filtre
ncfile.close()


### graphique

# fond de carte
xmin = min(lon_erai)
xmax = max(lon_erai)
ymin = min(lat_erai)
ymax = max(lat_erai)
map = Basemap(llcrnrlon=xmin,llcrnrlat=ymin,urcrnrlon=xmax,urcrnrlat=ymax,fix_aspect=False)

### K-means ni centre ni reduit
figure(figsize=(12, 6))
gs = gridspec.GridSpec(1, 1)
gs.update(left=0.08, right=0.98, wspace=0.18,top=.94,bottom=.05,hspace=0.15)
cmap = cm.get_cmap('jet', nbc*nbc_f+nbc_l)
ax1=subplot(gs[0, 0])
ax1.set_title('ERAI Classification - sea: %d-%d (%d) - land: %d-%d (%d)'%(1,nbc*nbc_f,nbc*nbc_f,nbc*nbc_f+1,nbc*nbc_f+nbc_l,nbc_l))
cax1=map.imshow((classif_glob-.5),interpolation='nearest',cmap=cmap, extent=[xmin,xmax,ymin,ymax],origin='upper',aspect='auto',vmin=0.5,vmax=17.5)
map.drawcoastlines()
map.drawmeridians(arange(xmin,xmax,50),labels=[1,1,0,1])
map.drawparallels(arange(ymin,ymax,10),labels=[1,1,0,1])
hc=colorbar(cax1)
hc.set_ticks(arange(nbc*nbc_f+nbc_l)+1)


draw()
#savefig('classERAI_globe.png',format='png',dpi=100)
show()
