function [fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour)

%MSGbuildfullfilename permet d'obtenir le chemin d'accès à un fichier
%netCDF, de données de température de brillance par MSG, pour la date
%désirée.

%
%+
%
% =======================
% MSGbuildfullfilename.m
% =======================
%
% .. function:: MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour)
%
% DESCRIPTION
% ===========
%
% - Données d'entrées :
%
%   * ncfilesset (en caractères) : Type de fichier netCDF que l'on cherche,
%     'normal' ou 'extracted'.
%   * Annee (en caractères) : Année (AAAA) du jour d'étude.
%   * Mois (en caractères) : Numéro du mois (MM) du jour d'étude.
%   * Jour (en caractères) : Numéro du jour d'étude (JJ).
%
% - Données de sorties :
%
%   * fullfilename : Chemin d'accès au fichier pour la date désirée.
%
% Cette fonction permet d'obtenir le chemin d'accès à un fichier NetCDF,
% de données de température de brillance par MSG, pour la date désirée.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`varamma_startup.m`
%
% :func:`MSGread`
%
% TODO
% ====
%
% add demo extracted
%
% test if file exists and handling error
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/MSGbuildfullfilename.m $
%
% - fplod 20110801T134631Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * date is a reserved word : replaced by date_file
%
% - jaclod 2011-07-26
%
%   * Révision de la documentation et des commentaires.
%
% - jaclod 2011-07-21
%
%   * Adaptation pour les fichiers 'extracted'.
%
% - jaclod 2011-07-13
%
%   * Création
%
%-

% Appel de la variable globale 'PROJECT_ID' (Il faut auparavant avoir
% exécuté 'varamma_startup').
global PROJECT_ID

usage='[fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% Création d'une variable comportant la date nous permettant de
% sélectionner le fichier en question.
date_file = ([Annee '-' Mois '-' Jour]);

% Le répertoire où se trouve le fichier, ainsi que son nom, différent selon
% qu'il soit 'normal' (fichier original) ou 'extracted' (fichier avec
% extraction des données spatiales).
switch ncfilesset

    case 'normal'

        % Répertoire contenant le fichier souhaité.
        repertoire = [ PROJECT_ID 'MSG/' Annee '/' Mois '/' ];

        % Création du chemin complet.
        fullfilename = [repertoire 'msg-tb108_' date_file '_15min.nc'];

case 'extracted'

        % Répertoire contenant le fichier souhaité.
        repertoire = [ PROJECT_ID 'MSG/extracted/' Annee '/' Mois '/' ];

        % Création du chemin complet.
        fullfilename = [repertoire 'extracted-msg-tb108_' date_file '_15min.nc'];

    otherwise

        error('La variable ncfilesset doit être ''normal'' ou ''extracted''.');

end

end

%!demo
%! varamma_startup;
%! more off;
%! Annee = '2006';
%! Mois = '07';
%! Jour = '28';
%! ncfilesset = 'normal';
%! [fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour)
