function [result] = M_compar_tbnoyau_image(Tb_SeuilSup, Tb_LimNoyau_ini, dTb_LimNoyau, Tps_SeuilInf)

%M_COMPAR_TBNOYAU_IMAGE boucle la fonction de comparaison EPSAT/MSG
%compar_tbnoyau_image.m sur plusieurs jours.

%
%+
%
% ========================
% M_compar_tbnoyau_image.m
% ========================
%
% .. function:: M_compar_tbnoyau_image(Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, Tps_SeuilInf)
%
% DESCRIPTION
% ===========
%
% - Données d'entrées :
%
%   * Tb_SeuilSup : Seuil de température de brillance maximale
%     délimitant un nuage convectif.
%   * Tb_LimNoyau_ini : Seuil de température de brillance délimitant le noyau
%     dans notre modèle à deux couches. Valeur de départ.
%   * dTb_LimNoyau : Variation du seuil de température de brillance du
%     noyau des nuages. Cette variation est appliquée à 4 reprises.
%   * Tps_SeuilInf : Critère de temps minimum de vie d'un nuage pour qu'il
%     soit pris en compte (en nombre de quarts d'heure, 3 par défaut).
%
% boucle sur la fonction de comparaison EPSAT/MSG :func:`compar_tbnoyau_image`
% sur plusieurs jours (la semaine d'étude est entre le 26 et le 31 juillet
% 2006).
%
% EXAMPLES
% ========
%
% Voir "demo".
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`data_epsat`
%
% :func:`compar_tbnoyau_image`
%
% TODO
% ====
%
% check arg
%
% hard code date time
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/M_compar_tbnoyau_image.m $
%
% - fplod 20110805T141546Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * remove interactivity
%
% - fplod 20110804T143713Z aedon.locean-ipsl.upmc.fr (Darwin)
%  
%   * add result
%
% - fplod 20110304T083154Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix rst header
%
% - jaclod 20110303
%
%   * Ajout de la doc et de la démonstration
%
% - jaclod 20110303
%
%   * Création
%
%-
result=-1;

usage='[result] = M_compar_tbnoyau_image(Tb_SeuilSup, Tb_LimNoyau_ini, dTb_LimNoyau, Tps_SeuilInf)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
%%%%%%%%%%%%%
% Paramètres
%%%%%%%%%%%%%

% On se place dans le mois de Juillet 2006.
Annee = '2006';
Mois = '07';

%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%
% Boucle sur les jours
%%%%%%%%%%%%%%%%%%%%%%%

for jour = 26:31;

    % On enregistre la variable Jour sous forme 'string' pour la suite.
    Jour = num2str(jour);

    % On ouvre une nouvelle figure pour ce jour.
    figure;

    % On lance la fonction de comparaison d'images EPSAT / MSG pour ce jour
    % et pour les paramètres précédemment définit.
    result=compar_tbnoyau_image(Annee, Mois, Jour, Tb_SeuilSup, Tb_LimNoyau_ini, dTb_LimNoyau, Tps_SeuilInf);

end

result=0;

end

%!demo
%! clear all
%! close all
%! varamma_startup;
%! more off
%! Tb_SeuilSup = 235;
%! Tb_LimNoyau_ini = 180;
%! dTb_LimNoyau = 10;
%! Tps_SeuilInf = 3;
%! result = M_compar_tbnoyau_image(Tb_SeuilSup, Tb_LimNoyau_ini, dTb_LimNoyau, Tps_SeuilInf);
