function [Annee, Mois, Jour] = compar_tbnoyau_disp(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax, Tps_SeuilInf, Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, nbclasses)

%COMPAR_TBNOYAU_DISP +todo+

%
%+
%
% =====================
% compar_tbnoyau_disp.m
% =====================
%
% .. function:: compar_tbnoyau_disp(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax, Tps_SeuilInf, Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, nbclasses)
%
% DESCRIPTION
% ===========
%
% - Données d'entrées :
%
%   * Annee (en caractères) : Année (AAAA) du jour d'étude.
%   * Mois (en caractères) : Numéro du mois (MM) du jour d'étude.
%   * Jour (en caractères) : Numéro du Jour d'étude (JJ).
%
%   :param lonmin: longitude min, W < 0
%   :units lonmin: deg
%   :type lonmin: double
%   :raise lonmin: required
%
%   :param lonmax: longitude max, W < 0
%   :units lonmax: deg
%   :type lonmax: double
%   :raise lonmax: required
%
%   :param latmin: latitude min, N > 0
%   :units latmin: deg
%   :type latmin: double
%   :raise latmin: required
%
%   :param latmax: latitude max, N > 0
%   :units latmax: deg
%   :type latmax: double
%   :raise latmax: required
%
%   * Tps_SeuilInf : Critère de temps minimum de vie d'un nuage pour qu'il
%     soit pris en compte (en nombre de quarts d'heure, 3 par défaut).
%   * Tb_SeuilSup_ini : Seuil de température de brillance maximale
%     délimitant un nuage convectif. Valeur de départ pour la comparaison.
%   * dTb_SeuilSup : Variation du seuil de température de brillance des
%     nuages. Cette variation est appliquée à 4 reprises.
%   * Tb_LimNoyau : Seuil de température de brillance délimitant le noyau
%     dans notre modèle à deux couches.
%   * nbclasses : +todo+
%
% - Données de sorties :
%
%   * Annee (en caractères) : Année (AAAA) du jour d'étude.
%   * Mois (en caractères) : Numéro du mois (MM) du jour d'étude.
%   * Jour (en caractères) : Numéro du Jour d'étude (JJ).
%
% EXAMPLES
% ========
%
% Voir "demo".
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`data_epsat`
%
% :func:`MSGread`
%
% :func:`intensityMSG_day`
%
% :func:`EPSATread`
%
% :func:`cumulEPSAT_day`
%
% :func:`histo_cumulEPSAT`
%
% :func:`histo_intensityMSG`
%
% TODO
% ====
%
% - fplod 20110609T070939Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * pb octave cratos
%
%     warning: division by zero
%     warning: division by zero
%     compar_tbnoyau_disp example 1: failed
%     reshape: size must be nonnegative
%
% add demo with simul_epsat and simul_msg
%
% complete description
%
% pourquoi renvoyer Annee mois jour ?
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/compar_tbnoyau_disp.m $
%
% - fplod 20110830T074359Z cratos (Linux)
%
%   * suppress interactivity
%
% - pinsard 2011-06-08T15:23:35Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * add box paramater
%
% - fplod 20110309T165844Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * suppress fontsize and fontname (known problem for octave)
%
% - fplod 20110309T163405Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * complete function definition with input parameters
%
% - fplod 20110304T083934Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix rst header
%
% - jaclod 20110303
%
%   * Ajout de la doc et de la démonstration
%
% - jaclod 20110303
%
%   * Création
%
%-

usage='[Annee, Mois, Jour] = compar_tbnoyau_disp(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax, Tps_SeuilInf, Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, nbclasses)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
%%%%%%%%%%%%%
% Paramètres
%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%
% Histogramme EPSAT
%%%%%%%%%%%%%%%%%%%%

% On lit le fichier EPSAT correspondant à notre date. (On ne se sert pas du
% "Temps" mais si on ne le met pas, il y a un problème au niveau des
% variables de sorties).
[PluieEPSAT, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = EPSATread(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax);

% On calcule le cumule des précipitations.
[CumulEPSAT] = cumulEPSAT_day(PluieEPSAT);

% On trace la distribution des précipitations cumulées dans une première zone.
subplot(2,3,1);
histo_cumulEPSAT(CumulEPSAT, Annee, Mois, Jour, nbclasses)

% On modifie le titre.
title(['Distributions des précipitations pour le ',...
    ([Annee '-' Mois '-' Jour])])

%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%
% Histogrammes MSG
%%%%%%%%%%%%%%%%%%%

% On lit le fichier MSG correspondant à notre date.
[TbMSG, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = MSGread(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax);

% On boucle ensuite pour avoir différent paramètres et, pour chaque cas,
% calculer l'intensité et tracer l'image.
for i=1:5;

    % On calcule l'intensité.
    Tb_SeuilSup = Tb_SeuilSup_ini + (i-1)*dTb_SeuilSup;
    [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau, TbMSG] = intensityMSG_day(Temps, TbMSG, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau);

    % On trace la distribution des intensités.
    subplot(2,3,i+1);
    histo_intensityMSG(ij_intensity, Annee, Mois, Jour, nbclasses);

    % On modifie le titre.
    title(['Distributions des intensités avec un seuil de ' num2str(Tb_SeuilSup) 'K'])

end

%%%%%%%%%%%%%%%%%%%
whos

end

%!demo
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '07';
%! Jour = '27';
%! latmin = 10;
%! latmax = 20;
%! lonmin = -20;
%! lonmax = -10;
%! nbclasses = 10;
%! Tb_SeuilSup_ini = 210;
%! dTb_SeuilSup = 10;
%! Tb_LimNoyau = 190;
%! Tps_SeuilInf = 3;
%! [Annee_out, Mois_out, Jour_ou] = compar_tbnoyau_disp(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax, Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, Tps_SeuilInf, nbclasses);
