; docformat = 'rst'
;+
; .. _cresamsu_cdf.pro:
;
; ======================
; cresamsu_cdf.pro
; ======================
;
; programme d'interpolation avec algorithme de Cressman
; adaptation aux données Tb AMSU lues avec la nouvelle chaîne de lecture
; extract_amsuab.pro
; correct_nadir.pro
;
; but: faire des fichiers "grilles" pour analyse statistique avec
; interpolation spatiale et temporelle
;
; Uses:
; paramètres:
; use_amsua = 0 ou 1 (amsub ou les deux)
;
; listcanal= tableau des canaux à traiter (caractères) ex ['a5', 'b5']
;
; .. code-block:: idl
;
;    cresamsu_cdf,use_amsua,yyyyb,mmb,ddb,yyyye,mme,dde,lonmin,lonmax, latmin, latmax,listcanal
;
; :Examples:
;
; .. code-block:: idl
;
;   listcanal=['a5']
;   use_amsua=1
;   yyyyb=2006L
;   yyyye=2006L
;   mmb=08
;   mme=8
;   ddb=1
;   dde=3
;   lonmin=-20
;   lonmax=40
;   latmin=0
;   latmax=30
;   cresamsu_cdf,use_amsua,yyyyb,mmb,ddb,yyyye,mme,dde,lonmin,lonmax, latmin, latmax,listcanal
;
; :Restrictions:
;
; :Pre:
;
; :Post:
;
; :Also:
;
;  :ref:`traite_amsuab.sh`
;
; :Todo:
;
; lelod 2011/10/27
; modifier correct_nadir_amsu.pro pour créer des fichiers AMSUa et
; AMSUb séparés pour garder la pleine résolution de chaque
; instrument jusqu'à l'interpolation dans une grille régulière
;
; lelod 2011/10/24
; actuellement codes en dur
; passer le choix du rayon de Cressman en paramètres
; rayon temporel rtemp (en jour decimal)
; rayon horizontal rhor (km)
; et la résolution
; pash (horizontale, en degré)
; past (temporelle, en jour décimal)
; et enfin l'heure d'interpolation heurinterp (en heures)
;
; envisager que seulement certains choix soient possibles après tests
; par exemple optimisation pour utilisation amsua ou amsub
;
; envisager possibilité de ne traiter que les orbites du matin ou du
; soir comme teste sur ClimServ, par ajout de ce critère sur variable
; lue "hour" dans le test sur le début et la fin des données utiles
;
; coding rules
;
; new filename convention
;
; :History:
;
; 20111121 lelod
; récupération du paramètre "orbit" dans le fichier lu :
; pour permettre ajustement en latitude des pseudopixels qui servent a
; tenir compte de l'élargissement des taches au sol
;
; 2011/11/20
; le programme fonctionne sur un fichier nadir même d'un seul
; jour. Le pb est qu'il finit avec une erreur (% Program caused
; arithmetic error: Floating illegal operand)
; je ne sais pas pourquoi! attention, l'appel à cresamsu_cdf
; est en commentaire
;
; 2011/10/27 lelod
; prise en compte de l'espacement croissant des pixels dans la fauchée
; et de l'élargissement correspondant de la tache au sol
; test de la méthode avec approximation sauvage swath ==variations en
; longitude
; par rapport au pixel central:
; à partir de fov=+/-11, dédoublement du pixel pixel +/- diamètre tache au sol/6
; à partir de fov=+/-14, pixel triple centre et +/- diamètre tache au sol/4
;
; 2011/10/24 lelod
; prise en compte des modifications de lecture et correction nadir
; (correct_nadir.pro):
; possibilité de traiter amsua et amsub ou amsub seul
; utilisation de pixelsize.pro pour boucher les trous entre lignes de
; pixels en bordure de fauchée de façon correcte
;
; $Id$
;
; $URL$
;
; - fplod 20110505T123230Z cratos.locean-ipsl.upmc.fr (Linux)
;
;   * minimal header
;
; - le 20110504
;
;-

pro cresamsu_cdf,use_amsua,yyyyb,mmb,ddb,yyyye,mme,dde,lonmin, lonmax, latmin, latmax,listcanal

; les paramètres de l'interpolation

; grille de sortie en long / lat
; reçoit en entrée les jours de l'année jdeb et jfin correspondant au début et la fin du mois
;=============================================================================================

compile_opt idl2, strictarrsubs
@cm_project

tbmin=100
tbmax=350
; est il utile d'avoir encore les seuils sur les Tbs à cette
; étape? Vérifier le passage des NaN

; résolution spatiale et temporelle de la grille de sortie
pash=0.5 ; en degré
pastemp=1 ; ennb revisites par jour - choix d'un nb entier par jour (0.25, 0.5 ou 1)
heurinterp=6. ; heure des tableaux interpolés (choix lié aux heures de passage satellites) si pas de temps eq 1
; sinon fixer heurinterp comme l'heure minimale pour l'interpolation
; (= rtemp???)
heurfin=heurinterp
; unités utilisées pour le temps: heure décimale
pasthor=pastemp*24.

; rayons de cressmann
rhor=60. ; en gros deux fois la résolution de AMSUB, et proche de celle d'AMSUA
rtemp=0.5 ;en jours rayon de Cressman (0.25, 0.5, 1, 2,... - nb entiers!)
r2=rhor*rhor
rtemphor=rtemp*24. ; en heures
print,'rayon temporel en heures',rtemphor
; valeurs utiles et conversion degré / radian
vbidon=-999.
coef=!pi/180.
rterre=6400.
rhdeg=rhor*180./(rterre*!pi)    ;rayon de Cressman en degré

; début et fin de la grille temporelle, à partir des fichiers d'entrée
; en j juliens : tient compte du rayon de Cressman temporel (rtemp)
if (heurinterp/24.le rtemp and rtemp lt 1) then begin
    heurinterp=rtemp*24.
    heurfin=24.-rtemp*24.
endif
jdeb=julday(mmb,ddb,yyyyb,heurinterp)
jfin=julday(mme,dde,yyyye,heurfin)
if (rtemp ge 1) then begin
    jdeb=julday(mmb,ddb+rtemp,yyyyb,heurinterp)
    jfin=julday(mme,dde+1-rtemp,yyyye,heurfin)
endif
hrdeb=jdeb*24
hrfin=jfin*24
print,'debut et fin', jdeb,jfin

; grille des données en sortie
lo1=lonmin+rhdeg
lo2=lonmax-rhdeg
la1=latmin+rhdeg
la2=latmax-rhdeg
print,"bornes de la grille de sortie",lo1,lo2,la1,la2,jdeb,jfin
kmax=fix((lo2-lo1)/pash) ; pour valeurs de 0 a kmax
nblon=kmax+1
lmax=fix((la2-la1)/pash) ; valeurs de 0 a lmax
nblat=lmax+1
jmax=fix((hrfin-hrdeb)/pasthor) ; valeurs de 0 a jmax
nbjour=jmax+1
print,'nb pas de temps',nbjour, ' nb lat',nblat,' nblon',nblon

;____________________________________
; pour le fichier netCDF
;------------------------------------
; coordonnées des points de la grille en sortie
los=coef*(indgen(nblon)*pash+lo1) ; en radians
las=coef*(indgen(nblat)*pash+la1) ; idem
xxlon=(indgen(nblon)*pash+lo1) ; en degres
yylat=(indgen(nblat)*pash+la1) ; en degres
jjours=indgen(nbjour)*pastemp+jdeb
lo2=max(xxlon)
la2=max(yylat)
hrfin=max(jjours)*24.
print, 'pas de temps du fichier netCDF en jours décimaux',jjours
print,'derniers points de la grille',max(xxlon),max(yylat),hrfin
;-----------------------------------
t=indgen(nbjour)*pasthor+hrdeb ; en heures
print,'t',t
; dimension des pixels dans la fauchée (swath) et dans le sens du "track"
; utiliser les dimensions amsua si use_amsua=1
; valeurs en km
 pixelsize, swatha,swathb,tracka,trackb

; boucle sur les canaux
list=listcanal
print,'les canaux',list

for jj=0L, n_elements(list)-1L do begin
    print,'canal---', listcanal[jj]
    numch=listcanal[jj]
    ; initialisation des tableaux de sortie (s valeurs, z poids, kont nb points)
    stb1=fltarr(nblon,nblat,nbjour)
    kont1=intarr(nblon,nblat,nbjour)
    z1=fltarr(nblon,nblat,nbjour)
    tb1fin=fltarr(nblon,nblat,nbjour)
    ; boucle sur les fichiers
    ; lecture des données et calcul des points interpolés
    ; lecture du fichier ajusté au nadir
    ; lecture séquentielle des données d'entrée et ajout aux points de grille
    ; concernés
    ;window,0
    if (use_amsua eq 1) then begin
        prefix='amsua_amsub_'
    endif else begin
        prefix='amsub_'
    endelse
    cont1=110L
    cont2=120L
    look = 'filename'
    geomin = geolocation_to_string_idl(lonmin, latmin, look,1)
    geomax = geolocation_to_string_idl(lonmax, latmax, look,1)

    for yyyy=yyyyb,yyyye do begin
        for mm=mmb,mme do begin
            for dd=ddb,dde do begin

                fichier2=project_id_env+ 'AMSU/' $
                + string(yyyy,format='(I4.4)') + '/' $
                + string(mm,format='(I2.2)')   + '/' $
                + prefix+string(yyyy,format='(I4.4)') $
                + string(mm,format='(I2.2)') $
                + string(dd,format='(I2.2)') + '_' $
                + geomin + '_' $
                + geomax $
                + '_nadir.dat'

                openr,2,fichier2, ERROR = error
                IF (error NE 0) then begin
                    ras = report(['eee : can not open for reading '$
                    + '!C' $
                    + 'code : ' + !ERROR_STATE.MSG $
                    + fichier2])
                    STOP
                ENDIF

                print,fichier2
                cont=0L
                while (not eof(2)) do begin
                    ;lecture nouveaux formats de données
                    if (use_amsua eq 1) then begin
                        readf,2, month,land_sea,yrday,orbit,hour,fov,nosat,lon,lat,zen,$
                        ach1,ach2,ach3,ach4,ach5,ach6,ach7,ach8,ach15,bch1,bch2,bch3,bch4,bch5,$
                        format='(4(i3,1x),f8.4,2i3,20(1x,f8.3))'
                    endif else begin
                        readf,2, month,land_sea,yrday,orbit,hour,fov,nosat,lon,lat,zen,bch1,bch2,bch3,bch4,bch5,$
                        format='(4(i3,1x),f8.4,2i3,8(1x,f8.3))'
                    endelse
                    cont=cont+1
                    if (use_amsua eq 1) then begin
                        if numch eq 'a1' then tb1=ach1
                        if numch eq 'a2' then tb1=ach2
                        if numch eq 'a3' then tb1=ach3
                        if numch eq 'a4' then tb1=ach4
                        if numch eq 'a5' then tb1=ach5
                        if numch eq 'a6' then tb1=ach6
                        if numch eq 'a7' then tb1=ach7
                        if numch eq 'a8' then tb1=ach8
                        if numch eq 'a15' then tb1=ach15
                    endif
                    if numch eq 'b1' then tb1=bch1
                    if numch eq 'b2' then tb1=bch2
                    if numch eq 'b3' then tb1=bch3
                    if numch eq 'b4' then tb1=bch4
                    if numch eq 'b5' then tb1=bch5
                    ;if (tb1 ne !values.f_Nan) then begin
                    if (tb1 ge tbmin and tb1 le tbmax) then begin
                    ;if  ((tb1 lt tbmin) or (tb1 gt tbmax)) then goto,suite0 ;; on ne s'intéresse pas aux données aberrantes
; à remplacer par if tb1 ne NaN then begin
;if (cont lt 10) then print,lon,lat,fov,tb1,hour
; test sur le début et la fin des données utiles tenant compte du rayon temporel
                         jour=julday(mm,dd,yyyy,0)*24.+hour ; en heures décimales
                         ;if (cont lt 10) then print,mm,dd,yyyy,'jour julien lu (en heure)',jour
                         if ((jour ge hrdeb-rtemphor) and (jour le hrfin+rtemphor) and (hour le 24.)) then begin
                            ; print,'on cherche les données dans la fenêtre temporelle'
                                ; utilisation seulement des orbites du
                                ; matin - projet heat low
; grilles temporelle et spatiale utile
                             jdp=fix((jour-hrdeb-rtemphor)/pasthor)>0
                             jfn=fix((jour-hrdeb+rtemphor)/pasthor)+1<jmax
                             ;print,'grille utile temporelle',jdp,jfn
                             kdp=fix((lon-lo1-rhdeg)/pash)>0
                             kfn=fix((lon-lo1+rhdeg)/pash)+1<kmax
                             ldp=fix((lat-la1-rhdeg)/pash)>0
                             lfn=fix((lat-la1+rhdeg)/pash)+1<lmax
                             ;print,'grille spatiale utile', kdp,kfn,ldp,lfn
                             ; calcul de la fonction de Cressman
                             ; ajout de points pour tenir compte de l'espacement des pixels
; dans la fauchée. Pour AMSUA, à partir du fov 11/15 de part et
; d'autre
; pour 11 - 13: remplacement du pixel central par deux pixels répartis
;           de swath/6 de part et d'autre, avec même Tb
; pour 14 et 15: complément du pixel central par deux pixels
; supplémentaires a +/- swath/4 avec même Tb
; prévoir même analyse pour amsub
; pour ajuster aussi la latitude, nec tenir compte de l'orbite
; montante ou descendante, qui dépend de l'heure pour chaque
; satellite!!! (voir si on peut récupérer cette info dans extractamsu.pro
                    ; if (use_amsua eq 1) then begin
                        swath=swatha
                        deltalat=0.1  ; écart de latitude entre pixels de bout de fauchée
                        fov_min=1
                        fov_max=30
                        fov_edge1=2
                        fov_edge2=29
                        fov_int1=3
                        fov_int2=5
                        fov_int3=26
                        fov_int4=28
                    ; endif
                     if (fov ge fov_min and fov le fov_edge1) or (fov ge fov_edge2 and fov le fov_max) then begin
                       ; print,'bord de fauchée'
                        lolo=fltarr(3)
                        lala=fltarr(3)
                        lolo[0]=lon-swath[fov-1]/(4.*rterre*coef)
    ; horrible approximation de décalage de position
                        lolo[1]=lon
                        lala[1]=lat
                        lolo[2]=lon+swath[fov-1]/(4.*rterre*coef)
;traitement de la latitude: orbite descendante
                        if (orbit eq 1) then begin
                            lala[0]=lat-deltalat/4.
                            lala[2]=lat+deltalat/4.
                            endif else begin
                               lala[0]=lat+deltalat/4.
                               lala[2]=lat-deltalat/4.
                               endelse
                        for ilolo=0,2 do begin
   ;  if (cont gt cont1 and cont lt cont2) then print,'pixels extremes',cont,fov,lolo[ilolo],lala[ilolo]
                           yy=lala[ilolo]*coef
                           xx=lolo[ilolo]*coef
                           coyy=cos(yy)
                           coxx=cos(xx)
                           sixx=sin(xx)
                           siyy=sin(yy)
; boucle pour le calcul des contributions aux points de la grille (los, las, t)
                           for nj=jdp,jfn do begin
                              dij=(jour-t[nj])/rtemphor ; normalisée par le rayon de Cressman
                              disj=dij*dij
                              for l=ldp,lfn do begin
                                  coco=coyy*cos(las[l])
                                  sisi=siyy*sin(las[l])
                                  for k=kdp,kfn do begin
                                      xxs=los[k]
                                      ang=coco*(coxx*cos(xxs)+sixx*sin(xxs))+sisi
                                      vv=ang
                                      ac=acos(vv)
                                      dist=rterre*rterre*ac*ac/r2
                                      if (dist lt 1. and disj lt 1.) then begin
                                         rnorm=2.
                                         poids=(rnorm-dist-disj)/(rnorm+dist+disj)
                                         stb1[k,l,nj]=stb1[k,l,nj]+tb1*poids
                                         z1[k,l,nj]=z1[k,l,nj]+poids
                                         kont1[k,l,nj]=kont1[k,l,nj]+1
                                      endif
                                   endfor
                                endfor
                            endfor
                        endfor
                     endif
                     if (fov ge fov_int1 and fov le fov_int2) or (fov ge fov_int3 and fov le fov_int4) then begin
; on ne traite pas le point central
                        lolo=fltarr(2)
                        lala=fltarr(2)
                        lolo[0]=lon-swath[fov-1]/(6.*rterre*coef)
                        lolo[1]=lon+swath[fov-1]/(6.*rterre*coef)
;traitement de la latitude: orbite descendante
                       if (orbit eq 1) then begin
                           lala[0]=lat-deltalat/6.
                           lala[1]=lat+deltalat/6.
                       endif else begin
                           lala[0]=lat+deltalat/6.
                           lala[1]=lat-deltalat/6.
                       endelse
                       for ilolo=0,1 do begin
    ;  if (cont gt cont1 and cont lt cont2) then print,'pixels intermédiaires',cont,fov,lolo[ilolo],lala[ilolo]
                           yy=lala[ilolo]*coef
                           xx=lolo[ilolo]*coef
                           coyy=cos(yy)
                           coxx=cos(xx)
                           sixx=sin(xx)
                           siyy=sin(yy)
; boucle pour le calcul des contributions aux points de la grille (los, las, t)
                           for nj=jdp,jfn do begin
                              dij=(jour-t[nj])/rtemphor ; normalisée par le rayon de Cressman
                              disj=dij*dij
                           for l=ldp,lfn do begin
                                 coco=coyy*cos(las[l])
                                 sisi=siyy*sin(las[l])
                                 for k=kdp,kfn do begin
                                    xxs=los[k]
                                    ang=coco*(coxx*cos(xxs)+sixx*sin(xxs))+sisi
                                    vv=ang
                                    ac=acos(vv)
                                    dist=rterre*rterre*ac*ac/r2
                                    if (dist lt 1. and disj lt 1.) then begin
                                       rnorm=2.
                                       poids=(rnorm-dist-disj)/(rnorm+dist+disj)
                                       stb1[k,l,nj]=stb1[k,l,nj]+tb1*poids
                                       z1[k,l,nj]=z1[k,l,nj]+poids
                                       kont1[k,l,nj]=kont1[k,l,nj]+1
                                   endif
                                 endfor
                              endfor
                           endfor
                        endfor
                     endif

; cas normal: milieu de la fauchée
                     ;print,'cas normal'
                     if (fov gt fov_int2 and fov lt fov_int3) then begin
           ;  if (cont gt cont1 and cont lt cont2) then print,'orbite',orbit,'pixels centraux',cont,fov,lon,lat
                         yy=lat*coef
                         xx=lon*coef
                         coyy=cos(yy)
                         coxx=cos(xx)
                         sixx=sin(xx)
                         siyy=sin(yy)
; boucle pour le calcul des contributions aux points de la grille
; (los, las, t)
                         for nj=jdp,jfn do begin
                             dij=(jour-t[nj])/rtemphor ; normalisée par le rayon de Cressman
                             disj=dij*dij
                             for l=ldp,lfn do begin
                                 coco=coyy*cos(las[l])
                                 sisi=siyy*sin(las[l])
                                 for k=kdp,kfn do begin
                                     xxs=los[k]
                                     ang=coco*(coxx*cos(xxs)+sixx*sin(xxs))+sisi
                                     vv=ang
                                     ac=acos(vv)
                                     dist=rterre*rterre*ac*ac/r2
                                     if (dist lt 1. and disj lt 1.) then begin
                                         rnorm=2.
                                         poids=(rnorm-dist-disj)/(rnorm+dist+disj)
                                               stb1[k,l,nj]=stb1[k,l,nj]+tb1*poids
                                               z1[k,l,nj]=z1[k,l,nj]+poids
                                               kont1[k,l,nj]=kont1[k,l,nj]+1
                                               ; print,kont1[k,l,nj]
                                           endif
                                       endfor
                                   endfor
                               endfor
                           endif
                        endif
                    endif            ; fin test données NaN
                endwhile

                close,2
            endfor
        endfor
    endfor

    good=where (kont1 ge 1,nb)
    print,'points valides',nb
    if (nb ne 0) then tb1fin[good]=stb1[good]/z1[good]
    bad=where (kont1 eq 0,nbad)
    print,'bad',nbad
    if (nbad ne 0) then tb1fin[bad]=!values.f_Nan
    ; print,tb1fin
    print,'extrêmes du compteur',min(kont1),max(kont1)

    ;toto=reform(tb1fin[*,*,0])
    ;plt,xxlon,yylat,toto
    idl_amsu_netcdf, numch, tb1fin, yylat, xxlon, jjours
endfor

end
