; docformat = 'rst'
;+
;
; .. _define_amsub_header_struct.pro:
;
; ==============================
; define_amsub_header_struct.pro
; ==============================
;
; Define AMSU-B Level 1C Header structure
; Ralf Bennartz 21 May 1999
;
; :Restrictions:
;
; :Returns:
;
; :Uses:
;
; :Pre:
;
; :Post:
;
; :Todo:
;
; :Examples:
;
; .. code-block:: idl
;
;    define_amsub_header_struct
;    help, /structure
;    ...
;    ** Structure AMB_HEAD, 26 tags, length=4608, data length=4608:
;       H_SITE          BYTE      Array[3]
;       H_CFILL1        BYTE      
;       H_1BSITE        BYTE      Array[3]
;       H_CFILL2        BYTE      
;       H_VERSNB        LONG      
;       H_VERSYR        LONG      
;       H_VERSDY        LONG      
;       H_HDRCNT        LONG      
;       H_SATID         LONG      
;       H_INSTRUMENT    LONG      
;       H_SATHT         LONG      
;       H_PERIOD        LONG      
;       H_STARTORBIT    LONG                                      
;       H_STARTDATAYR   LONG                                      
;       H_STARTDATADY   LONG                                      
;       H_STARTDATATIME LONG                                      
;       H_ENDORBIT      LONG                                      
;       H_ENDDATAYR     LONG                                      
;       H_ENDDATADY     LONG                                      
;       H_ENDDATATIME   LONG                                      
;       H_SCNLIN        LONG                                      
;       H_MISSCNLIN     LONG                                      
;       H_VNANTENNACORR LONG                                      
;       H_SPARE         LONG                                      
;       H_TEMPRADCNV    LONG      Array[3, 5]                     
;       H_FILLER        LONG      Array[1115]       
;    ;    
;
; :History:
;
;   $Id: define_amsub_header_struct.pro 235 2011-05-16 15:52:50Z pinsard $
;
; - fplod 20100701T130054Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
PRO define_amsub_header_struct
;
compile_opt idl2, strictarrsubs
;
COMMON amsub_header,amb_head
;
bnchan = 5
;
amb_head={ amb_head,$
            h_site          : BYTARR(3)   , $
            h_cfill1        : 0B          , $
            h_1bsite        : BYTARR(3)   , $
            h_cfill2        : 0B          , $
            h_versnb        : 0L          , $
            h_versyr        : 0L          , $
            h_versdy        : 0L          , $
            h_hdrcnt        : 0L          , $
            h_satid         : 0L          , $
            h_instrument    : 0L          , $
            h_satht         : 0L          , $
            h_period        : 0L          , $
            h_startorbit    : 0L          , $
            h_startdatayr   : 0L          , $
            h_startdatady   : 0L          , $
            h_startdatatime : 0L          , $
            h_endorbit      : 0L          , $
            h_enddatayr     : 0L          , $
            h_enddatady     : 0L          , $
            h_enddatatime   : 0L          , $
            h_scnlin        : 0L          , $
            h_misscnlin     : 0L          , $
            h_vnantennacorr : 0L          , $
            h_spare         : 0L          , $
            h_tempradcnv    : LONARR(3,bnchan) , $
            h_filler        : LONARR(1115)  $
         }
END
