; docformat = 'rst'
;+
;
;  .. function:: file_bathy_to_mem(lonmin, lonmax, latmin, latmax)
;
; .. _file_bathy_to_mem.pro:
;
; =====================
; file_bathy_to_mem.pro
; =====================
;
; DESCRIPTION
; ===========
;
; lit la carte de bathymétrie de S. Masson et remplit les tableaux du common ++
;
; .. only:: man or text
;
;    Figure is visible on PDF and HTML documents only.
;
; .. only:: html or latex
;
;     .. graphviz::
;
;        digraph file_bathy_to_mem {
;
;           bathy [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/MASK/ETOPO1_Ice_g_gmt4.nc"];
;           xxe [shape=tab,fontname=Courier,label="xxe array common"];
;           yye [shape=tab,fontname=Courier,label="yye array common"];
;           bate [shape=tab,fontname=Courier,label="bate array common"];
;
;           file_bathy_to_mem [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/file_bathy_to_mem.pro",
;           label="${PROJECT}/src/file_bathy_to_mem.pro"];
;
;           {bathy} -> {file_bathy_to_mem} -> {xxe yye bate}
;       }
;
; :param lonmin:
; :param lonmax:
; :param latmin:
; :param latmax:
;
; EXAMPLES
; ========
;
; .. code-block:: idl
;
;    lonmin=-25.
;    lonmax=25.
;    latmin=-5.
;    latmax=20.
;    result = file_bathy_to_mem(lonmin, lonmax, latmin, latmax)
;
; SEE ALSO
; ========
;
; :ref:`data_bathymetry`
;
; called by :ref:`traite_amsuab.sh`
;
; use ++
;
; next step :  ++
;
; TODO
; ====
;
; make it work : % Program caused arithmetic error: Floating illegal operand dans le read_netcf à la main
;
; improve log
;
; check args
;
; get rid of hard coded values -15, +15
;
; get rid of hard coded values XMINMESH=8000,XMAXMESH=15000, YMINMESH=4500,YMAXMESH=8500
; those ones are valid for West Africa ONLY
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - lelod 20121127
;
;   * introduction d'une interpolation bilinéaire de la topographie
;     pas réussi à faire marcher file_interp, donc création du tableau
;     interpole à l'appel (tres rapide) sur la zone choisie
;     la zone est codée comme latmin, lonmin -marge; latmax, lonmax +marge
;     marge codée en dur = 16
;
; - fplod 20120416
;
;   * creation from extract_amsua.pro
;
;-
function file_bathy_to_mem $
, lonmin, lonmax, latmin, latmax
;
compile_opt idl2, strictarrsubs
;
@cm_project
@common
; Return to caller if errors
ON_ERROR, 2
;
result = -1
;
s = size(SCOPE_TRACEBACK(/STRUCTURE),/DIMENSION)
routine = (SCOPE_TRACEBACK(/STRUCTURE))[s-1].Routine
;
if key_performance EQ 1 THEN BEGIN
    time1 = SYSTIME(1)
ENDIF
;
; lecture fichier land - sea (S. Masson)
file=project_id_env+'/MASK/ETOPO1_Ice_g_gmt4.nc'
;fileout=project_id_env+'/MASK/ETOPO1_interp.nc'

;  lonmin=0 & latmin=0
; lonmax=20 & latmax=20
; marge autour du domaine cible pour restriction des recherches dans l'orbite
marge=16.
xmin=(lonmin-marge+180)*60.
ymin=(latmin-marge+90.)*60.
xmax=(lonmax+marge+180)*60.
ymax=(latmax+marge+90.)*60.

;initncdf,file, zaxisname='toto',xaxisname='lon',yaxisname='lat',XMINMESH=8000,XMAXMESH=15000, YMINMESH=4500,YMAXMESH=8500
initncdf,file,zaxisname='toto',xaxisname='lon',yaxisname='lat',XMINMESH=xmin,XMAXMESH=xmax,YMINMESH=ymin,YMAXMESH=ymax
domdef,lonmin-marge, lonmax+marge, latmin-marge, latmax+marge

bathy=read_ncdf('z',file=file)
;bate=bathy.arr gt 0

xxe1=reform(glamt[*,0])
zonx=where(xxe1 ge lonmin-marge and xxe1 le lonmax+marge)
xxe2=xxe1[zonx]
yye1=reform(gphit[0,*])
zony=where(yye1 ge latmin-marge and yye1 le latmax+marge)
yye2=yye1[zony]
;xxf=fltarr(max(size(zonx))/2,max(size(zony))/2)
;yyf=fltarr(max(size(zonx))/2,max(size(zony))/2)
;for j=0,max(size(zony))/2-1 do xxf(*,j)=indgen(max(size(xxe))/2)*2*(max(xxe)-min(xxe))/max(size(xxe))+min(xxe)
;for i=0,max(size(zonx))/2-1 do yyf(i,*)=indgen(max(size(yye))/2)*2*(max(yye)-min(yye))/max(size(yye))+min(yye)
xxf=indgen(max(size(xxe2))/3)*3
yyf=indgen(max(size(yye2))/3)*3
Result = bilinear( bathy.arr,xxf, yyf)
xxe=indgen(max(size(xxe2))/3)*3*(max(xxe2)-min(xxe2))/max(size(xxe2))+min(xxe2)
yye=indgen(max(size(yye2))/3)*3*(max(yye2)-min(yye2))/max(size(yye2))+min(yye2)
bate=result gt 0.

IF key_performance EQ 1 THEN BEGIN
    msg = report(['ppp : ' + routine + ' : durée totale ' $
    + string(SYSTIME(1)-time1,format='(F12.6)')])
ENDIF
;
result = 0
return, result
end
