; docformat = 'rst'
;+
;
;  .. function:: file_correcb_to_mem(lonmin, lonmax, latmin, latmax)
;
; .. _file_correcb_to_mem.pro:
;
; =======================
; file_correcb_to_mem.pro
; =======================
;
; DESCRIPTION
; ===========
;
; lit les fichiers de correction amsub generes par MLL et remplit les
;tableaux du common ++
; en entree, besoin du nom du satellite (N18 et N19_MHS, N15 ou
; N16_AMSUB, M02_MHS), et le no du canal AMSUB/MHS (de 1 à 5)
; A prevoir, canaux 1 à 6 de SAPHIR
; fichiers mensuels de resolution ERA-interim en lon, lat, pour les
; 90 points de fauchee
; il faut donc lui donner la date pour charger seulement le fichier du
;mois en cours
;
; .. only:: man or text
;
;    Figure is visible on PDF and HTML documents only.
;
; .. only:: html or latex
;
;     .. graphviz::
;
;        digraph file_correcb_to_mem {
;
;           correcb [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/MASK/ETOPO1_Ice_g_gmt4.nc"];
;           xxe [shape=tab,fontname=Courier,label="xxe array common"];
;           yye [shape=tab,fontname=Courier,label="yye array common"];
;           correc [shape=tab,fontname=Courier,label="bate array common"];
;
;           file_correcb_to_mem [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/file_bathy_to_mem.pro",
;           label="${PROJECT}/src/file_bathy_to_mem.pro"];
;
;           {correcb} -> {file_correcb_to_mem} -> {xxe yye correc}
;       }
;
; :param lonmin:
; :param lonmax:
; :param latmin:
; :param latmax:
;
; EXAMPLES
; ========
;
; .. code-block:: idl
;
;    nomsat=M02_MHS
;    nocanal=3
;    mois=3
;    lonmin=-25.
;    lonmax=25.
;    latmin=-5.
;    latmax=20.
;    result = file_correcb_to_mem(nomsat, nocanal, mois, lonmin, lonmax, latmin, latmax)
;

; TODO
; ====
;
;
; EVOLUTIONS
; ==========
;
; lelod 20140725 ecrit sur la base de file_bathy_to_mem.pro
; $Id: file_bathy_to_mem.pro 635 2014-03-27 15:11:49Z pinsard $
;
; $URL: svn+ssh://lelod@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/file_bathy_to_mem.pro $
;

;-
function file_correcb_to_mem, nomsat, mois, nocanal, lonmin, lonmax, latmin, latmax
;
compile_opt idl2, strictarrsubs
;
@cm_project
@common
; Return to caller if errors
ON_ERROR, 2
;
result = -1
;
s = size(SCOPE_TRACEBACK(/STRUCTURE),/DIMENSION)
routine = (SCOPE_TRACEBACK(/STRUCTURE))[s-1].Routine
;
if key_performance EQ 1 THEN BEGIN
    time1 = SYSTIME(1)
ENDIF
;
; lecture fichier 
file=project_id_env+'/CORRTB/corrtb_'+nomsat+'_L1C_B'+string(nocanal,I1)+'_fus.nc'
mois=
; marge autour du domaine cible pour restriction des recherches dans l'orbite
marge=16.
xmin=(lonmin-marge+180)*60.
ymin=(latmin-marge+90.)*60.
xmax=(lonmax+marge+180)*60.
ymax=(latmax+marge+90.)*60.

;initncdf,file, zaxisname='toto',xaxisname='lon',yaxisname='lat',XMINMESH=8000,XMAXMESH=15000, YMINMESH=4500,YMAXMESH=8500
initncdf,file,xaxisname='lon',yaxisname='lat'
domdef,lonmin-marge, lonmax+marge, latmin-marge, latmax+marge

correc=read_ncdf('corrTb',file=file)
xgrid=read_ncdf('lon',file=file)
ygrid=read_ncdf('lat',file=file)
correcmois=reform(correc[mois,*,*,*]) ; attention ordre des variables????


; alternative saxo:
 correc=read_ncdf('corrTb',mois,mois,timevar='time',file = file)
 xgrid=lon & ygrid=lat
;????????????????

IF key_performance EQ 1 THEN BEGIN
    msg = report(['ppp : ' + routine + ' : durée totale ' $
    + string(SYSTIME(1)-time1,format='(F12.6)')])
ENDIF
;
result = 0
return, result
end
