function [result]=graphe_zicode(yyyy, nbligne, zi_code, seuil, classes_select, msdnom_select)

%GRAPHE_ZICODE appelle les programmes read_lai_gis.m et
%plot_lai_gis.m pour tracer le lai des différents types de sol
%et de classes de végétation dans chacune des zones d'intérêt définies autour
%des pluviomètres

%+
%
% ===============
% graphe_zicode.m
% ===============
%
% .. function:: graphe_zicode(yyyy, nbligne, zi_code, seuil, classes_select, msdnom_select)
%
% DESCRIPTION
% ===========
%
%    :param yyyy: year
%    :type yyyy: uint16
%    :raise yyyy: required
%
%    :param nbligne: nb ligne
%    :type nbligne: uint16
%    :raise nbligne: required
%
%    :param seuil: seuil
%    :type seuil: uint16
%    :raise seuil: required
%
%    :param zi_code: zi_code zone where we take data
%    :type zi_code: string
%
%    :param classes_select: classes we want to select ex: '"Savane herbacee et arbustive"'
%    :type classes_select: string
%    :raise classes_select: required
%
%    :param msdnom_select: msdnom we want to select ex: "FERRUGINEUX TROPICAUX"
%    :type msdnom_select: string
%    :raise msdnom_select: required
%
% graphe_zicode appelle les programmes :func:`read_lai_gis` et
% :func:`plot_lai_gis` pour tracer le lai des différents types de sol
% et de classes de végétation dans chacune des zones d'intérêt définies autour
% des pluviomètres
%
% If ``classes_select`` is set to **all**, all possible classes_values will be
% used to select data.
% If ``classes_select`` is empty (:samp:`''`), no criterium on classes_value value is
% applied to select data.
%
% If ``msdnom_select`` is set to **all**, all possible msdnom_values will be
% used to select data.
% If ``msdnom_select`` is empty (:samp:`''`), no criterium on msdnom_value value is
% applied to select data.
%
% ++ tracer de la moyenne et de l'écart-type du lai des classes de végétation
% correspondant à chaque type de sol autour de chaque pluviomètre pour
%
% ++for soil types and vegetation plot  LAI data
% each around rain gauges
% définit zones d'intérêt
%
% sur une zone pour un type de sol on regarde l'évolution des différentes
% classes de végétation
%
% SEE ALSO
% ========
%
% :ref:`data_lai`
% :ref:`zones`
%
% :func:`read_lai_gis`
% :func:`plot_lai_gis`
%
% TODO
% ====
%
% add imageprefix in parameter
%
% encore une bataille entre les type cell et char ... Pénible mais ça marche
%
% les messages genre
% :samp:`warning: ft_render: skipping missing glyph for character ..`
% sont liés à des pb de diacritiques dans les classes ou les msd
% ... Faire le ménage au niveau de la production
%
% comprendre pourquoi warning gnuplot broken pipe sur mac soclod
% (ce n'est pas le cas sous octave cratos)
%
% mieux gérer le retour de plot_lai_gis
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110929T140022Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add msdnom_select
%   * use **all** in msdnom_select and classes_value instead of empty string
%     to keep semantic homogenized between plot_lai_gis.m and graphe_zicode.m
%
% - soclod 20110928
%
%  * add classes_select parameter
%
% - soclod/fplod 20110927
%
%   * add seuil parameter
%
% - fplod 20110916T160617Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add demo for ferlo 2000
%
% - fplod 20110915T162406Z cratos (Linux)
%
%   * suppress gridcode_value from calls
%
% - fplod 20110823T135630Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * prise en compte de la nouvelle paramétrisation de plot_lai_gis
%     (classes_select et msdnom_select à la place de gridcode et msd)
%   * listes de classes_select et msdnom_select fabriquées à partir des
%     données passées en argument classes_value msdnom_value
%
% - fplod 20110823T124811Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * la gestion des figure est reportée dans plot_lai_gis.m
%
% - soclod 20110822
%
%   * change demos
%
% - soclod 20110819
%
%   * impression de toutes les figures sur des fenêtres différentes(ifigure)
%
% - fplod/soclod 20110818
%
%   *  supprimer gridcode et msd des paramètres
%
% - soclod 20110817
%
%   * creation
%
%-
%
result=-1;
%
usage='[result]=graphe_zicode(yyyy, nbligne, zi_code, seuil)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('yyyy');
if ~strcmp(arg_info.class,'uint16')
    disp(['Incorrect type of arg yyyy ' arg_info.class]);
   error(usage);
end
clear arg_info
%
arg_info=whos('nbligne');
if ~strcmp(arg_info.class,'uint16')
    disp(['Incorrect type of arg nbligne ' arg_info.class]);
    whos nbligne
      error(usage);
end
clear arg_info
%
arg_info=whos('zi_code');
if ~strcmp(arg_info.class,'char')
    disp(['Incorrect type of arg zi_code ' arg_info.class]);
    whos zi_code
    error(usage);
end
clear arg_info
%
arg_info=whos('seuil');
if ~strcmp(arg_info.class,'uint16')
    disp(['Incorrect type of arg seuil ' arg_info.class]);
    whos seuil
    error(usage);
end
clear arg_info
%
arg_info=whos('classes_select');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg classes_select ' arg_info.class]);
   whos classes_select
   error(usage);
end
clear arg_info
%
arg_info=whos('msdnom_select');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg msdnom_select ' arg_info.class]);
   whos msd
   error(usage);
end
clear arg_info
%
% lecture du fichier contenant les lai pour l'année demandée
[lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value]=read_lai_gis(yyyy, nbligne, zi_code);
%
if ~strcmp(classes_select,'all');
    list_classes_select = cellstr(classes_select);
else
    list_classes_select=unique(classes_value);
end
%
if ~strcmp(msdnom_select,'all');
    list_msdnom_select = cellstr(msdnom_select);
else
    list_msdnom_select=unique(msdnom_value);
end
%
imageprefix = '';

% boucle sur les valeurs de classes_values et de msdnom_value
if (numel(list_classes_select) > 0 && numel(list_msdnom_select) > 0)
   % boucle sur toutes les valeurs de msdnom_select
   for ind_msd=1:size(list_msdnom_select,1)
        disp(['ind_msd : ' num2str(ind_msd) ', msdnom_select : ' char(list_msdnom_select(ind_msd))])
       %
       % boucle sur toutes les valeurs de classes_select
       for ind_classes=1:numel(list_classes_select)
            disp([' ind_classes : ' num2str(ind_classes) ' ,classes_select : ' char(list_classes_select(ind_classes))]);
           % calcule les moyennes et écart-type non filtrés et filtrés
           % et produit une figure
           [lai_mean, lai_std]=plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, char(list_classes_select(ind_classes)), char(list_msdnom_select(ind_msd)), zi_code, imageprefix, seuil);
       end
   end
end

if isempty(classes_select)
   % disp(['iii : no classes_select criterium']);
    % boucle sur toutes les valeurs de msdnom_select
    for ind_msd=1:size(list_msdnom_select,1)
        % disp(['ind_msd : ' num2str(ind_msd) ', msdnom_select : ' char(list_msdnom_select(ind_msd))])
        [lai_mean, lai_std]=plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, char(list_classes_select(ind_classes)), char(list_msdnom_select(ind_msd)), zi_code, imageprefix, seuil);

    end
end
if isempty(msdnom_select)
    disp(['iii : no msdnom_select criterium']);
    for ind_classes=1:numel(list_classes_select)
         disp([' ind_classes : ' num2str(ind_classes) ' ,classes_select : ' char(list_classes_select(ind_classes))]);
        [lai_mean, lai_std]=plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, char(list_classes_select(ind_classes)), char(list_msdnom_select(ind_msd)), zi_code, imageprefix, seuil);
    end
end

result=0;
end

%!demo
%! % To plot ++ on each point with common classe_value and msdnom_value
%! % on a figure
%! % from the first 1000 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'ferlo';
%! classes_select = 'all';
%! msdnom_select = 'all';
%! seuil = uint16(100);
%! [result] = graphe_zicode(yyyy, nbligne, zi_code, seuil, classes_select, msdnom_select)

%!demo
%! % To plot ++ on each point with
%! % classes_value is "Savane arbustive arboree" and msdnom_value is each
%! % existing name in msdnom_value array
%! % on a figure
%! % from the first 1000 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkedji.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'barkedji';
%! classes_select = '"Savane arbustive arboree"';
%! msdnom_select = 'all';
%! seuil = uint16(100);
%! [result] = graphe_zicode(yyyy, nbligne, zi_code, seuil, classes_select, msdnom_select)

%!demo
%! % To plot ++ on each point with
%! % with classes_value is each existing name is classes_value array
%! % and msdnom_value is "FERRUGINEUX TROPICAUX"
%! % on a figure
%! % from the first 1000 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkedji.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'barkedji';
%! classes_select = 'all';
%! msdnom_select = '"FERRUGINEUX TROPICAUX"';
%! seuil = uint16(100);
%! [result] = graphe_zicode(yyyy, nbligne, zi_code, seuil, classes_select, msdnom_select)

%!demo
%! % To plot ++ on each point with
%! % with no selection on classes_value and no selection on msdnom_value
%! % on a figure
%! % from the first 1000 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkedji.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'barkedji';
%! classes_select = '';
%! msdnom_select = '';
%! seuil = uint16(100);
%! [result] = graphe_zicode(yyyy, nbligne, zi_code, seuil, classes_select, msdnom_select)
