;+
;
; .. _plot_amsu.pro:
;
; =============
; plot_amsu.pro
; =============
;
; DESCRIPTION
; ===========
;
; prgm de visualisation des fichiers AMSU à partir des fichiers journaliers
; crées par extract_amsua.pro
;
; :param numch:
; :param yyyy:
; :param mm:
; :param lonmin:
; :param lonmax:
; :param latmin:
; :param latmax:
;
; EXAMPLES
; ========
;
; Using AMSU-A channel 5:
;
; .. code-block:: idl
;
;    numch = 'a5'
;    yyyy=2006L
;    mm=8
;    dd=13
;    resol=1
;    lonmin=-60.
;    lonmax=50.
;    latmin=-30.
;    latmax=45.
;    plot_amsu, numch, yyyy, mm, dd, lonmin, lonmax, latmin, latmax
;
; :file:`${PROJECT_ID}/AMSU/2006/08/a5_20060813_060w30s_050e45n.dat`
; must have been created first

; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20120323
;
;   * header revision
;
; - lelod 2012/02/23
;
;   * created
;
;-
pro plot_amsu, numch,yyyy,mm,dd,lonmin,lonmax,latmin,latmax

compile_opt idl2, strictarrsubs

@cm_project
testfilename=''
prefix=numch
look = 'filename'

geomin = geolocation_to_string_idl(lonmin, latmin, look,1)
geomax = geolocation_to_string_idl(lonmax, latmax, look,1)

result=file_amsu_t2_to_mem( yyyy,mm,dd,numch,lonmin,lonmax,latmin,latmax,testfilename)
         desc=result.data.desc
         hour=result.data.hour
         fov=result.data.fov
         lon=result.data.lon
         lat=result.data.lat
         mask=result.data.landseamask
         tb1=result.data.tb
         ; décodage du nb de points (nn)
         nn=n_elements(tbinit)
print,'fauchée',min(fov),max(fov)
print,'nb orbites',max(desc)

; plot orbites du matin
tbmin=100.
tbmax=300.
;jnd=where(tb1 gt tbmin and tb1 lt tbmax and mask eq 1 and hour le 12)
rep=''
descmin=0 & descmax=max(desc)

lab_orbite:
print,'no d orbite min et max?'
read,descmin,descmax

window,0
loadct,39
jnd=where(tb1 gt tbmin and tb1 lt tbmax and desc ge descmin and desc le descmax)
tb=tb1[jnd]
lolo=lon[jnd]
lala=lat[jnd]
for ide=descmin,descmax do print,'heure des orbites tracées',mean(hour[ide])
plot,lon,lat,xrange=[lonmin,lonmax],yrange=[latmin,latmax],xstyle=1,ystyle=1,/nodata
colscale=intarr(n_elements(tb))
for j=0,n_elements(tb)-1 do colscale[j]=(tb[j]-min(tb))*255/(max(tb)-min(tb))
plots,lolo,lala,psym=5,symsize=1,color=colscale
ind=where mask gt 0 and mask lt 1
plots,lon(ind),lat(ind),psym=1, symsize=1,color=0
print,'autres orbites? (oui ou ...)'
read,rep
if rep eq 'oui' then goto,lab_orbite

;mer=0
;if mer ne 0 then begin
; plot sur ocean
;    tbmin=200. & tbmax=280.
;    jnd=where(tb1 gt tbmin and tb1 lt tbmax and mask eq 0)
;    tb=tb1[jnd]
;    lolo=lon[jnd]
;    lala=lat[jnd]
;    print,'ocean ',min(tb),max(tb)
;    window,1
;    loadct,39
;    plot,lon,lat,xrange=[lonmin,lonmax],yrange=[latmin,latmax],xstyle=1,ystyle=1,/nodata
;    colscale=intarr(n_elements(tb))
;    for j=0,n_elements(tb)-1 do colscale[j]=(tb[j]-min(tb))*255/(max(tb)-min(tb))
;    plots,lolo,lala,psym=5,symsize=1,color=colscale
;endif

end
