function [result] = plot_intensityMSG(ij_intensity, Annee, Mois, Jour, Longitudes, Latitudes)

%PLOT_INTENSITYMSG dessine les intensités de l'activité nuageuse, estimées
%d'après les données MSG et notre modèle à deux couches, dans notre
%domaine d'étude sur une journée.

%
%+
%
% ===================
% plot_intensityMSG.m
% ===================
%
% .. function:: plot_intensityMSG(ij_intensity, Annee, Mois, Jour, Longitudes, Latitudes)
%
% DESCRIPTION
% ===========
%
% - Données d'entrées :
%
%   * Annee (en caractères) : Année (AAAA) du jour d'étude.
%   * Mois (en caractères) : Numéro du mois (MM) du jour d'étude.
%   * Jour (en caractères) : Numéro du Jour d'étude (JJ).
%   * Longitudes : Variable de longitudes dans le domaine [20°W 10°W].
%   * Latitudes : Variable de latitudes dans le domaine [10°N 20°N].
%   * ij_intensity : Données d'intensités estimées sur une journée dans
%     notre domaine d'étude.
%
% Dessin des intensités de l'activité nuageuse, estimées d'après les
% données MSG et notre modèle à deux couches, dans notre domaine d'étude
%
% EXAMPLES
% ========
%
% Voir "demo".
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :func:`MSGread`
%
% :func:`intensityMSG_day`
%
% :func:`ticklatlon`
%
% TODO
% ====
%
% make demo work : now pb with intensityMSG_day
%
% very strange figure produce by demo : check handling of "0" data
%
% save figure
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/plot_intensityMSG.m $
%
% - fplod 20110609T094258Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * demo with :func:`simul_msg`
%
% - pinsard 2011-05-26T07:52:18Z loholt1.ipsl.polytechnique.fr
%
%   * suppress full screen
%
% - fplod 20110309T170307Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * suppress fontsize and fontname (known problem for octave)
%
% - fplod 20110304T090001Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix rst header
%
% - jaclod 20110302
%
%   * Ajout de la doc et de la démonstration
%
% - jaclod 20110225
%
%   * Création
%
%-

result=-1;
%
usage='[result] = plot_intensityMSG(ij_intensity, Annee, Mois, Jour, Longitudes, Latitudes)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%

%%%%%%%%%%%%%
% Paramètres
%%%%%%%%%%%%%

latmin = 10;
latmax = 20;
lonmin = -20;
lonmax = -10;

%%%%%%%%%%%%%


% Chargement des fichiers pour tracer les côtes.
load coast;

% Les données dont la valeur est 0 passent à "NaN" pour ne pas être
% affichées dans l'image.
ij_intensity(ij_intensity == 0) = NaN;

% Ouverture/Modification d'une figure
figure()

% On trace l'intensité.
image = imagesc(Longitudes,Latitudes,ij_intensity');
set(image,'alphadata',~isnan(ij_intensity'));

% Modification des axes.
axis([lonmin lonmax latmin latmax]);
set(gca,'ydir','normal');

hold on
colorbar;

% Ajout des côtes.
plot(long,lat,'k-');

% Ajout de titres.
xlabel('Longitudes')
ylabel('Latitudes')
title(['Intensités pour le ' ([Annee '-' Mois '-' Jour])])

% Execution de la fonction permettant d'afficher les coordonnées en format
% °N/S et °E/W.
status_ticklatlon=ticklatlon();

% Ajout d'une grille.
grid on;

result=0;

whos

end

%!demo
%! % From scratch with simulated data during 1 day::
%! varamma_startup;
%! more off
%! index_simulation=uint8(3);
%! [lon_value, lat_value, datejul_value, datestr_value, TbMSG]=simul_msg(index_simulation);
%! [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau, TbMSG] = intensityMSG_day(Temps, TbMSG);
%! result=plot_intensityMSG(ij_intensity, Annee, Mois, Jour, Longitudes,Latitudes);

%!demo
%! % From real  file :file:`${PROJECT_ID}/MSG/2006/08/msg-tb108_2006-08-01_15min.nc`::
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! latmin = 10;
%! latmax = 20;
%! lonmin = -20;
%! lonmax = -10;
%! [TbMSG, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = MSGread(Annee, Mois, Jour, lonmin, lonmax, latmin, latmax);
%! [ij_intensity, Tps_SeuilInf, Tb_SeuilSup, Tb_LimNoyau, TbMSG] = intensityMSG_day(Temps, TbMSG);
%! result = plot_intensityMSG(ij_intensity, Annee, Mois, Jour, Longitudes,Latitudes);
