function [date_deb,date_fin, date_laimax,duree_anomali,date_anomalie,dates_anomalies,dates_anomali,fin_anomalie,duree_pause_moy]=plot_lai_parameterscycle(datejul_value,datestr_value,lai_mean,lai_std,annee);
%
%PLOT_LAI_MEANZONESBIS_LE plot ++
%
%+
% ==========================
% plot_lai_meanzonesbis_le.m
% ==========================
%
% .. function:: plot_lai_parameterscycle(datejul_value,datestr_value,lai_mean,lai_std,annee)
%
% DESCRIPTION
% ===========
%
%    :param datejul_value: dates in days number
%    :type datejul_value: uint16
%    :raise datejul_value: required
%
%    :param datestr_value: dates in format ex: dd/mm/yyyy
%    :type: datestr_value: uint16
%    :raise datestr_value: required
%
%    :param lai_mean: data mean
%    :type lai_mean: integer
%    :raise lai_mean: required
%
%    :param lai_std: data std
%    :type lai_std: integer
%    :raise lai_std: required
%
%     :param annee: year
%     :type annee: uint16
%     :raise annee: required ex 2000
%
% EXAMPLES
% ========
%
% see demos
%
% TIPS
% ====
%
% SEE ALSO
% ========
%
% :ref:`data_lai`
% :ref:`zones`
%
% :func:`read_lai_gis`
% :func:`plot_lai_spline_detect_anomalies`
%
% TODO
% ====
%
% add simulation demo
%
% diviser par un seuil adéquat pour toutes les années et les entités ex 30
%
% automatiser sur toutes les années
%
% EVOLUTIONS
% ==========
%
% $Id: plot_lai_meanzonesbis_le.m 2012-09-01 12:39:38Z soclod $
%
% $URL: svn+ssh://soclod@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/plot_lai_meanzonesbis_le.m $
%
% - soclod 20120901
%
%   * detection start day and dates anomalies for vegetation (entités)
%
% - lelod 20120903
%
%   * change programme
%
%   * add seuil parameter and step of data
%
% - soclod 20120904
%
%  * plot figure des entités with adjustment du seuil ex 30;10;20
%
%-

    zi_code='ferlo'
    imageprefix= ''
    % appel le programme plot_lai_spline_detect_anomalies qui
    % calcule les maximas et les minimas
    [laispw2,y,maxtabv_ext,mintabv_ext,maxtab_ext,mintab_ext]=plot_lai_spline_detect_anomalies(datejul_value, datestr_value, zi_code,imageprefix,lai_mean,lai_std);
    datevecteur=datevec(datejul_value);
    annee=datevecteur(1,1);

    % datejul=datevec2doy(datevec(datejul_value));
    datejul=datejul_value-datenum(annee,1,1);
    %ind_date=find(datejul>=152)
    % on cherche les maximas et minimas entre le 1er juin et le 30 novembre
    ddeb=datenum(annee,6,1)-datenum(annee,1,1);
    dfin=datenum(annee,11,30)-datenum(annee,1,1);
    % ind_date est l'indice des dates comprises entre le 1er juin et
    % le 30 novembre
    ind_date=find(datejul>= ddeb & datejul<=dfin);
    ind_maxtab=find(maxtab_ext(:,1)>=ddeb & maxtab_ext(:,1)<=dfin);
    maxtab_fin=maxtab_ext(ind_maxtab)

    %recherche date debut vegetation
    indbase=find(datejul<ddeb);
    % lai avant le 1er juin
    laibase=mean(lai_mean(indbase));

    datejul_utile=datejul(ind_date);
    % lai correspondant à la période d 1er juin au 30 novembre
    lai_utile=lai_mean(ind_date);
    %
    dem_lai=find((lai_utile-laibase)>=(max(lai_utile)-laibase)/30.)
    date_deb_lai=datejul_utile(dem_lai(1))
    % indices des écarts inférieurs à 8 (le pas de temps)
    indpic=find(abs(maxtab_fin-date_deb_lai)<=8);
    % la date qu'il faut garder pour le tracer et pour les recherches d'anomalie
    date_deb=maxtab_fin(indpic)

    % recherche les anomalies
    ind_mint=find(mintab_ext(:,1)>=date_deb & mintab_ext(:,1)<=dfin);
    date_anomalie=mintab_ext(ind_mint)

    % recherche des reprises de vegetation (maxima)
    % calcul de la durée des anomalies
    duree_anomalie=zeros(size(date_anomalie));
    lmax=length(date_anomalie);

    for l=1:lmax-1;
        ind=find(maxtab_fin > date_anomalie(l) & maxtab_fin <  date_anomalie(l+1));
        duree_anomalie(l)=maxtab_fin(ind)- date_anomalie(l);
    end
    ind=find(maxtab_fin > date_anomalie(lmax) & maxtab_fin <= dfin);
    if ind >0;
        duree_anomalie(lmax)=maxtab_ext(ind)-mintab_ext(lmax);
    end
    duree_anomalie=nonzeros(duree_anomalie);
    date_anomalie=date_anomalie(find(nonzeros(duree_anomalie)))
    fin_anomalie=date_anomalie+duree_anomalie

    % calcul de la date du maximum de LAI
    lai_max=max(lai_utile);
    ind_maxlai=find(lai_utile == lai_max);
    date_maxlai=datejul_utile(ind_maxlai)

end
