#!/usr/bin/env python
# -*- coding: utf-8 -*-

__docformat__ = 'reStructuredText'
__autodoc__ = ['simul_msg_xrit_raw']

import sys
import numpy


def simul_msg_xrit_raw(index_simulation):
    """

    ==================
    simul_msg_xrit_raw
    ==================

    DESCRIPTION
    ===========

    Charge en mémoire des info simulées de produit contenu dans un MSG XRIT raw

    Simulation #1
      IR108 3712x3712 valeurs croissantes de 0 à (3712x3712)-1

    Parameters
    ----------

    index_simulation : {1}

    Returns
    -------

    values : numpy.ndarray
       values

    product : string
       product

    Raises
    ------

    Missing parameters

    EXAMPLES
    ========

    >>> # From scratch to create IR108 3712x3712 array::
    >>>
    >>> index_simulation = 1
    >>> (product, values, missing_value) = simul_msg_xrit_raw(index_simulation)
    >>> product
    'IR108'
    >>> values.strides
    (14848, 4)
    >>> values.shape
    (3712, 3712)
    >>> values.ndim
    2
    >>> print values[0,0]
    -999.0
    >>> print missing_value
    -999.0
    >>> n=3712
    >>> print ("values[n-1,n-1] %f (n=%d)" % (values[n-1,n-1], n)) #(3712*3712)-1
    values[n-1,n-1] 13778943.000000 (n=3712)

    To write these values in
    :file:`${PROJECT_OD}/MSG/2006/08/01/H-000-MSG1__-MSG1________-IR108____-CYCLE____-200608010000.write_msg_xrit_raw.raw`,
    see :func:`write_msg_xrit_raw`

    To plot the values :

    see :func:`plot_msg_xrit_raw`

    SEE ALSO
    ========

    :ref:`data_msg`

    :func:`write_msg_xrit_raw`
    :func:`plot_msg_xrit_raw`

    TODO
    ====

    finish

    missing values in simulation

    EVOLUTIONS
    ==========

    $Id$

    $URL$

    - pinsard 2013-07-31T11:32:44Z loholt1.ipsl.polytechnique.fr (Linux)

      * add missing_value

    - pinsard 20130730T135417Z loholt1.ipsl.polytechnique.fr (Linux)

      * creation draft

    """

    result = -1
    #
    usage = '(product, values, missing_value) = simul_msg_xrit_raw(index_simulation)'

    if index_simulation == 1:
        product = 'IR108'
        n = 3712
    else:
        print ('eee : unknown simulation %i' % (index_simulation))
        sys.exit(1)

    values = []

    if index_simulation == 1:
        missing_value = -999.
        values = numpy.arange(n*n, dtype=numpy.float32).reshape(n, n)
        values[0, 0] = missing_value
    else:
        print ('eee : unknown simulation %i' % (index_simulation))
        sys.exit(1)
    #
    result = 0
    #
    return product, values, missing_value

# Run main, if called from the command line
if __name__ == '__main__':
    import doctest
    doctest.testmod()
