function [uniquerandvalues] = uniquerand(N, minvalue, maxvalue)

%UNIQUERAND est une fonction permettant de trouver N valeurs aléatoires
%entières et uniques réparties uniformément dans un intervalle donné.

%
%+
%
% =============
% uniquerand.m
% =============
%
% .. function:: uniquerand(N, minvalue, maxvalue)
%
% DESCRIPTION
% ===========
%
% - Données d'entrées :
%
%   * N : Nombres de valeurs aléatoires entières et uniques que l'on
%     souhaite.
%   * minvalue : Borne inférieure de l'intervalle dans lequel on souhaite
%     avoir les valeurs.
%   * maxvalue : Borne supérieure de l'intervalle dans lequel on souhaite
%     avoir les valeurs.
%
% - Données de sorties :
%
%   * uniquerandvalues : Vecteur lignes comportant les N valeurs aléatoires
%     entières et uniques dans l'intervalle défini par minvalue et
%     maxvalue.
%
% Cette fonction permet de trouver N valeurs aléatoires entières et uniques
% reparties uniformément dans un intervalle donné.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% describe demo
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/uniquerand.m $
%
% - jaclod 2011-07-28
%
%   * Creation.
%
%-
usage='[uniquerandvalues] = uniquerand(N, minvalue, maxvalue)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% Verification que l'intervalle comporte plus de nombres entiers que de
% valeurs demandées.
if N > fix(maxvalue)-ceil(minvalue)+1;
    error('Vous demandez plus de valeurs entières uniques qu''il n''en existe dans l''intervalle donnée.');
end

% Création d'un vecteur ligne de valeurs entières aléatoires comprises
% entre les valeurs minimales et maximales.
uniquerandvalues = round(minvalue + (maxvalue - minvalue)*(rand(1,N)));

% Suppression des éventuelles valeurs répétitives.
uniquerandvalues = unique(uniquerandvalues);

% S'il nous manque désormais des valeurs, on en reprend jusqu'à avoir
% définitivement N valeurs aléatoires entières et uniques.
while size(uniquerandvalues,2) ~= N;

    % On cherche combien il manque de valeurs.
    n = N - size(uniquerandvalues,2);

    % On rajoute les n valeurs manquantes.
    uniquerandvalues = cat(2,uniquerandvalues,round(minvalue + (maxvalue - minvalue)*(rand(1,n))));

    % Suppressions des nouvelles éventuelles valeurs répétitives.
    uniquerandvalues = unique(uniquerandvalues);

end

clear('N','minvalue','maxvalue','n');

end

%!demo
%! [uniquerandvalues] = uniquerand(20, 10, 50);
